from setuptools import setup, find_packages
import codecs
import os



VERSION = '0.1.0'
DESCRIPTION = 'IdeaScale Package'

# Setting up
setup(
    name="ideascale",
    version=VERSION,
    author="Tien Nguyen",
    author_email="tiennguyenhotel97@gmail.com",
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires=['pandas','openpyxl','xlsxwriter','jinja2'],
    keywords=['python', 'xlsxformatting', 'Mardown'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
